## 📖 Vetores de conhecimento 
## **Armazenando e categorizando conhecimento** 
- **06/01/2024**  
  - Conceito: Usaremos um dicionario com categorias de conhecimentos que de vetores , podendo ser anexado no agente e apos o uso desanexado , Cada um vector_store pode conter até 10.000 arquivos. Os armazenamentos de vetores podem ser anexados a Assistentes e Threads. Hoje, você pode anexar no máximo um armazenamento de vetores a um assistente e no máximo um armazenamento de vetores a um thread.